

DataBase Manager (Python ORM) Project
===============
This module can be used to manage the data base.
Just with make a dictionary to do all CRUD operations on the data base.
Installing
============

.. code-block:: bash

    pip install db_manager_py

Usage
=====

.. code-block:: bash

    >>> from src.main import db_manager_py
    >>> db_manager.get_sklearn_version()
    '0.1.1'
    >>> from src.main import db_manager_py
    >>> db_manager.get_sklearn_version()
    '0.1.1'
    >>> from src.main import db_manager
    >>> db_manager.get_sklearn_version()
    '0.1.1'